@@ -48,6 +48,9 @@ public:
         ReplicationSourceModelRole,
         ReplicationSourceIndexRole,
         ReplicasModelRole,
+        CapabilitiesRole,
+        OverscanRole,
+        VrrPolicyRole,
     };
 
     explicit OutputModel(ConfigHandler *configHandler);
@@ -121,6 +124,7 @@ private:
      * @param dest the desired destination to be adjusted by snapping
      */
     void snap(const Output &output, QPoint &dest);
+    void maintainSnapping(const Output &changedOutput, const QSize &oldSize, const QSize &newSize);
 
     bool setEnabled(int outputIndex, bool enable);
 
