@@ -18,23 +18,23 @@
 
 #include "osdtest.h"
 
-#include <QGuiApplication>
 #include <QCommandLineParser>
+#include <QGuiApplication>
 
 int main(int argc, char **argv)
 {
     QGuiApplication app(argc, argv);
 
-    QCommandLineOption dbus = QCommandLineOption(QStringList() << QStringLiteral("d") << QStringLiteral("dbus"),
-                                                  QStringLiteral("Call over dbus"));
-    QCommandLineOption outputid = QCommandLineOption(QStringList() << QStringLiteral("o") << QStringLiteral("outputidentifiers"),
-                                                  QStringLiteral("Show output identifier"));
+    QCommandLineOption dbus = QCommandLineOption(QStringList() << QStringLiteral("d") << QStringLiteral("dbus"), QStringLiteral("Call over dbus"));
+    QCommandLineOption outputid =
+        QCommandLineOption(QStringList() << QStringLiteral("o") << QStringLiteral("outputidentifiers"), QStringLiteral("Show output identifier"));
     QCommandLineOption icon = QCommandLineOption(QStringList() << QStringLiteral("i") << QStringLiteral("icon"),
-                                                  QStringLiteral("Icon to use for OSD"), QStringLiteral("preferences-desktop-display-randr"));
+                                                 QStringLiteral("Icon to use for OSD"),
+                                                 QStringLiteral("preferences-desktop-display-randr"));
     QCommandLineOption message = QCommandLineOption(QStringList() << QStringLiteral("m") << QStringLiteral("message"),
-                                                  QStringLiteral("Icon to use for OSD"), QStringLiteral("OSD Test"));
-    QCommandLineOption selector = QCommandLineOption({ QStringLiteral("s"), QStringLiteral("selector") },
-                                                  QStringLiteral("Show new screen action selector"));
+                                                    QStringLiteral("Icon to use for OSD"),
+                                                    QStringLiteral("OSD Test"));
+    QCommandLineOption selector = QCommandLineOption({QStringLiteral("s"), QStringLiteral("selector")}, QStringLiteral("Show new screen action selector"));
     KScreen::OsdTest osdtest;
     QCommandLineParser parser;
     parser.addHelpOption();
@@ -45,8 +45,6 @@ int main(int argc, char **argv)
     parser.addOption(selector);
     parser.process(app);
 
-
-
     if (parser.isSet(dbus)) {
         osdtest.setUseDBus(true);
     }
@@ -57,8 +55,7 @@ int main(int argc, char **argv)
     } else {
         osdtest.showGenericOsd(parser.value(icon), parser.value(message));
     }
-    if (parser.isSet(outputid)) {
-    }
+    if (parser.isSet(outputid)) { }
 
     return app.exec();
 }
